@@ -8,7 +8,7 @@
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
-# Copyright (c) 2004-2007 Kenneth J. Pronovici.
+# Copyright (c) 2004-2008 Kenneth J. Pronovici.
 # All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
@@ -27,7 +27,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: collect.py 1181 2007-03-25 16:18:22Z pronovic $
+# Revision : $Id: collect.py 915 2008-04-28 03:21:50Z pronovic $
 # Purpose  : Implements the standard 'collect' action.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -126,14 +126,16 @@ def executeCollect(configPath, options, config):
          collectMode = _getCollectMode(config, collectDir)
          archiveMode = _getArchiveMode(config, collectDir)
          ignoreFile = _getIgnoreFile(config, collectDir)
+         linkDepth = _getLinkDepth(collectDir)
+         dereference = _getDereference(collectDir)
          digestPath = _getDigestPath(config, collectDir)
          tarfilePath = _getTarfilePath(config, collectDir, archiveMode)
          (excludePaths, excludePatterns) = _getExclusions(config, collectDir)
          if fullBackup or (collectMode in ['daily', 'incr', ]) or (collectMode == 'weekly' and todayIsStart):
             logger.debug("Directory meets criteria to be backed up today.")
             _collectDirectory(config, collectDir.absolutePath, tarfilePath, 
-                              collectMode, archiveMode, ignoreFile, resetDigest, 
-                              digestPath, excludePaths, excludePatterns)
+                              collectMode, archiveMode, ignoreFile, linkDepth, dereference,
+                              resetDigest, digestPath, excludePaths, excludePatterns)
          else:
             logger.debug("Directory will not be backed up, per collect mode.")
          logger.info("Completed collecting directory [%s]" % collectDir.absolutePath)
@@ -181,7 +183,8 @@ def _collectFile(config, absolutePath, tarfilePath, collectMode, archiveMode, re
 ###############################
 
 def _collectDirectory(config, absolutePath, tarfilePath, collectMode, archiveMode, 
-                      ignoreFile, resetDigest, digestPath, excludePaths, excludePatterns):
+                      ignoreFile, linkDepth, dereference, resetDigest, digestPath, 
+                      excludePaths, excludePatterns):
    """
    Collects a configured collect directory.
    
@@ -200,6 +203,8 @@ def _collectDirectory(config, absolutePath, tarfilePath, collectMode, archiveMod
    @param collectMode: Collect mode to use.
    @param archiveMode: Archive mode to use.
    @param ignoreFile: Ignore file to use.
+   @param linkDepth: Link depth value to use.
+   @param dereference: Dereference flag to use.
    @param resetDigest: Reset digest flag.
    @param digestPath: Path to digest file on disk, if needed.
    @param excludePaths: List of absolute paths to exclude.
@@ -209,7 +214,7 @@ def _collectDirectory(config, absolutePath, tarfilePath, collectMode, archiveMod
    backupList.ignoreFile = ignoreFile
    backupList.excludePaths = excludePaths
    backupList.excludePatterns = excludePatterns
-   backupList.addDirContents(absolutePath)
+   backupList.addDirContents(absolutePath, linkDepth=linkDepth, dereference=dereference)
    _executeBackup(config, backupList, absolutePath, tarfilePath, collectMode, archiveMode, resetDigest, digestPath)
 
 
@@ -384,6 +389,44 @@ def _getIgnoreFile(config, item):
    return ignoreFile
 
 
+############################
+# _getLinkDepth() function
+############################
+
+def _getLinkDepth(item):
+   """
+   Gets the link depth that should be used for a collect directory.
+   If possible, use the one on the directory, otherwise set a value of 0 (zero).
+   @param item: C{CollectDir} object
+   @return: Ignore file to use.
+   """
+   if item.linkDepth is None:
+      linkDepth = 0
+   else:
+      linkDepth = item.linkDepth
+   logger.debug("Link depth is [%d]" % linkDepth)
+   return linkDepth
+
+
+############################
+# _getDereference() function
+############################
+
+def _getDereference(item):
+   """
+   Gets the dereference flag that should be used for a collect directory.
+   If possible, use the one on the directory, otherwise set a value of False.
+   @param item: C{CollectDir} object
+   @return: Ignore file to use.
+   """
+   if item.dereference is None:
+      dereference = False
+   else:
+      dereference = item.dereference
+   logger.debug("Dereference flag is [%s]" % dereference)
+   return dereference
+
+
 ############################
 # _getDigestPath() function
 ############################
