@@ -8,7 +8,7 @@
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
-# Copyright (c) 2004-2007 Kenneth J. Pronovici.
+# Copyright (c) 2004-2007,2010 Kenneth J. Pronovici.
 # All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
@@ -27,7 +27,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: cli.py 894 2008-03-20 20:08:05Z pronovic $
+# Revision : $Id: cli.py 952 2010-01-10 20:11:53Z pronovic $
 # Purpose  : Provides command-line interface implementation.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -87,6 +87,7 @@ import getopt
 
 # Cedar Backup modules
 from CedarBackup2.release import AUTHOR, EMAIL, VERSION, DATE, COPYRIGHT
+from CedarBackup2.customize import customizeOverrides
 from CedarBackup2.util import RestrictedContentList, DirectedGraph, PathResolverSingleton
 from CedarBackup2.util import sortDict, splitCommandLine, executeCommand, getFunctionReference
 from CedarBackup2.util import getUidGid, encodePath, Diagnostics
@@ -243,6 +244,7 @@ def cli():
    try:
       logger.info("Configuration path is [%s]" % configPath)
       config = Config(xmlPath=configPath)
+      customizeOverrides(config)
       setupPathResolver(config)
       actionSet = _ActionSet(options.actions, config.extensions, config.options, 
                              config.peers, executeManaged, executeLocal)
@@ -300,8 +302,6 @@ class _ActionItem(object):
    type (_ActionItem before _ManagedActionItem) and then by index within type.
 
    @cvar SORT_ORDER: Defines a sort order to order properly between types.
-
-   @sort: __init__, index, module, function 
    """
    
    SORT_ORDER = 0
