@@ -27,7 +27,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Official Cedar Backup Extensions
-# Revision : $Id: subversion.py 761 2007-07-05 03:04:54Z pronovic $
+# Revision : $Id: subversion.py 935 2009-03-29 18:56:50Z pronovic $
 # Purpose  : Provides an extension to back up Subversion repositories.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -124,7 +124,7 @@ class RepositoryDir(object):
    Relative exclusions are allowed here.  However, there is no configured
    ignore file, because repository dir backups are not recursive.
 
-   @sort: __init__, __repr__, __str__, __cmp__, directoryPat, collectMode, compressMode
+   @sort: __init__, __repr__, __str__, __cmp__, directoryPath, collectMode, compressMode
    """
 
    def __init__(self, repositoryType=None, directoryPath=None, collectMode=None, compressMode=None,
