@@ -11,7 +11,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: release.py 950 2009-08-16 20:12:09Z pronovic $
+# Revision : $Id: release.py 957 2010-01-10 22:54:17Z pronovic $
 # Purpose  : Provides location to maintain release information.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -33,8 +33,8 @@ Provides location to maintain version information.
 
 AUTHOR      = "Kenneth J. Pronovici"
 EMAIL       = "pronovic@ieee.org"
-COPYRIGHT   = "2004-2009"
-VERSION     = "2.19.4"
-DATE        = "16 Aug 2009"
+COPYRIGHT   = "2004-2010"
+VERSION     = "2.19.5"
+DATE        = "10 Jan 2010"
 URL         = "http://cedar-backup.sourceforge.net/"
 
