@@ -27,7 +27,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: testutil.py 879 2008-03-20 04:00:23Z pronovic $
+# Revision : $Id: testutil.py 949 2009-08-16 20:04:58Z pronovic $
 # Purpose  : Provides unit-testing utilities.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -207,7 +207,10 @@ def extractTar(tmpdir, filepath):
    tmpdir = encodePath(tmpdir)
    filepath = encodePath(filepath)
    tar = tarfile.open(filepath)
-   tar.posix = False
+   try:
+      tar.format = tarfile.GNU_FORMAT
+   except:
+      tar.posix = False
    for tarinfo in tar:
       tar.extract(tarinfo, tmpdir)
 
@@ -501,18 +504,18 @@ def hexFloatLiteralAllowed():
    Indicates whether hex float literals are allowed by the interpreter.
 
    As far back as 2004, some Python documentation indicated that octal and hex
-   notation applies only to integer literals.  However, prior to Python 2.5, it
-   was legal to construct a float with an argument like 0xAC.  This check
-   provides a version-based indication of whether the current interpreter
+   notation applied only to integer literals.  However, prior to Python 2.5, it
+   was legal to construct a float with an argument like 0xAC on some platforms.
+   This check provides a an indication of whether the current interpreter
    supports that behavior.
 
    This check exists so that unit tests can continue to test the same thing as
    always for pre-2.5 interpreters (i.e. making sure backwards compatibility
    doesn't break) while still continuing to work for later interpreters.
 
-   The returned value is True for Python <= 2.5, and False otherwise.
+   The returned value is True if hex float literals are allowed, False otherwise.
    """
-   if map(int, [sys.version_info[0], sys.version_info[1]]) < [2, 5]:
+   if map(int, [sys.version_info[0], sys.version_info[1]]) < [2, 5] and not platformWindows():
       return True
    return False
 
