@@ -8,7 +8,7 @@
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
-# Copyright (c) 2007 Kenneth J. Pronovici.
+# Copyright (c) 2007-2008 Kenneth J. Pronovici.
 # All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
@@ -27,7 +27,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: dvdwriter.py 1193 2007-03-30 01:55:18Z pronovic $
+# Revision : $Id: dvdwriter.py 871 2008-03-19 01:27:24Z pronovic $
 # Purpose  : Provides functionality related to DVD writer devices.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -166,7 +166,7 @@ class MediaCapacity(object):
    Space used and space available do not include any information about media
    lead-in or other overhead.
 
-   @sort: __init__, bytesUsed, bytesAvailable
+   @sort: __init__, bytesUsed, bytesAvailable, totalCapacity, utilized
    """
 
    def __init__(self, bytesUsed, bytesAvailable):
@@ -177,6 +177,12 @@ class MediaCapacity(object):
       self._bytesUsed = float(bytesUsed)
       self._bytesAvailable = float(bytesAvailable)
 
+   def __str__(self):
+      """
+      Informal string representation for class instance.
+      """
+      return "utilized %s of %s (%.2f%%)" % (displayBytes(self.bytesUsed), displayBytes(self.totalCapacity), self.utilized)
+
    def _getBytesUsed(self):
       """
       Property target used to get the bytes-used value.
@@ -189,8 +195,26 @@ class MediaCapacity(object):
       """
       return self._bytesAvailable
 
+   def _getTotalCapacity(self):
+      """
+      Property target to get the total capacity (used + available).
+      """
+      return self.bytesUsed + self.bytesAvailable
+
+   def _getUtilized(self):
+      """
+      Property target to get the percent of capacity which is utilized.
+      """
+      if self.bytesAvailable <= 0.0:
+         return 100.0
+      elif self.bytesUsed <= 0.0:
+         return 0.0
+      return (self.bytesUsed / self.totalCapacity) * 100.0
+
    bytesUsed = property(_getBytesUsed, None, None, doc="Space used on disc, in bytes.")
    bytesAvailable = property(_getBytesAvailable, None, None, doc="Space available on disc, in bytes.")
+   totalCapacity = property(_getTotalCapacity, None, None, doc="Total capacity of the disc, in bytes.")
+   utilized = property(_getUtilized, None, None, "Percentage of the total capacity which is utilized.")
 
 
 ########################################################################
@@ -228,9 +252,8 @@ class DvdWriter(object):
       of DVD media.  It provides common operations for the device, such as
       ejecting the media and writing data to the media.
 
-      This class is implemented in terms of the C{eject}, C{growisofs} and
-      C{dvd+rw-mediainfo} utilities, all of which should be available on most
-      UN*X platforms.
+      This class is implemented in terms of the C{eject} and C{growisofs}
+      utilities, all of which should be available on most UN*X platforms.
 
    Image Writer Interface
    ======================
